@@ -29,13 +29,15 @@ class Notification(AbstractNotification):
 
 class UserCategorySettings(AbstractUserCategorySettings):
     class Meta(AbstractUserCategorySettings.Meta):
-        swappable = swappable_setting("txn_notifications",
-                                      "UserCategorySettings")
+        swappable = swappable_setting(
+            "txn_notifications", "UserCategorySettings"
+        )
         abstract = False
 
 
 class UserHandlerSettings(AbstractUserHandlerSettings):
     class Meta(AbstractUserHandlerSettings.Meta):
-        swappable = swappable_setting("txn_notifications",
-                                      "UserHandlerSettings")
+        swappable = swappable_setting(
+            "txn_notifications", "UserHandlerSettings"
+        )
         abstract = False
